@@ -73,7 +73,7 @@ ADRand = function(parameters) {
     parameters$random_seed = random_seed
 
     # Set the seed of R's random number generator.
-    # It also takes effect to Rcpp randome generation functions.
+    # It also takes effect to Rcpp random generation functions.
     # https://stackoverflow.com/questions/60119621/get-the-same-sample-of-integers-from-rcpp-as-base-r
     suppressWarnings(RNGkind(sample.kind = "Rounding"))
     set.seed(random_seed)
@@ -371,7 +371,7 @@ ADRand = function(parameters) {
     }
 
     if (!is.null(parameters$ncores)) {
-
+      # nocov start
       # Maximum number of cores
       max_ncores = parallel::detectCores()
 
@@ -386,7 +386,7 @@ ADRand = function(parameters) {
                             c("Value"),
                             "int",
                             NA) 
-
+      # nocov end
     } else {
       parameters$ncores = 1
     }
@@ -429,7 +429,7 @@ ADRand = function(parameters) {
     ncores = parameters$ncores
 
     if (ncores > 1) {
-
+      # nocov start
       cl = parallel::makeCluster(ncores)
 
       # Export all functions in the global environment to each node
@@ -463,7 +463,7 @@ ADRand = function(parameters) {
         adaptive = collect_adaptive_matrices,
         stage_sample_size = collect_stage_sample_size_matrices
       )
-
+      # nocov end
     } else {
 
       sim_results = ADRandSingleCore(parameters)
@@ -665,7 +665,7 @@ ADRandReportDoc = function(results) {
 
     # Error checks
 
-    if (class(results) != "ADRandResults") stop("The object was not created by the ADRand function.", call. = FALSE)
+    if (!is(results, "ADRandResults")) stop("The object was not created by the ADRand function.", call. = FALSE)
 
     #############################################################################
 
